pub struct HistoryEntry {
pub entry_uuid: Uuid,
pub expression: Token,
/* private fields */
}Expand description
Individual history entry retaining it’s UUID, parser tokens, and textual rendition.
Fields
entry_uuid: UuidUUID of the entry.
expression: TokenParser tokens of the entry, basically the entire expression parsed down into it’s most basic form
Implementations
Sourceimpl HistoryEntry
impl HistoryEntry
Sourcepub fn new(expression: &Token, session: &Session) -> Self
pub fn new(expression: &Token, session: &Session) -> Self
Creates a new entry struct from parser tokens and the desired amount of decimal places to render.
Sourcepub fn only_equality(&self) -> &Token
pub fn only_equality(&self) -> &Token
Gets the entry with only the equality
Sourcepub fn render_without_equality(&self, session: &Session) -> String
pub fn render_without_equality(&self, session: &Session) -> String
Renders the entry without an equal sign, nor everything right of it.
Just returns the expression unmodified if there is no equal sign.