pub struct VarTable {
pub variables: Vec<Variable>,
}Expand description
Struct for the built-in vartable type
Fields
variables: Vec<Variable>Vector of variables
Implementations
Sourceimpl VarTable
impl VarTable
Sourcepub fn merge(&mut self, vartable: &VarTable) -> Result<(), Box<dyn Error>>
pub fn merge(&mut self, vartable: &VarTable) -> Result<(), Box<dyn Error>>
Merge with another vartable, overwriting all existing variables with ones found in the other vartable
Sourcepub fn add(&mut self, var: Variable) -> Result<(), Box<dyn Error>>
pub fn add(&mut self, var: Variable) -> Result<(), Box<dyn Error>>
Add a variable to the VarTable, fail if the variable exists
Sourcepub fn remove(&mut self, id: &str) -> Result<(), Box<dyn Error>>
pub fn remove(&mut self, id: &str) -> Result<(), Box<dyn Error>>
Remove a variable from the VarTable given just the id, fail if the variable doesn’t exist