HistoryEntry

Struct HistoryEntry 

pub struct HistoryEntry {
    pub entry_uuid: Uuid,
    pub expression: Token,
    /* private fields */
}
Individual history entry retaining it’s UUID, parser tokens, and textual rendition.

Fields

entry_uuid: Uuid

UUID of the entry.

expression: Token

Parser tokens of the entry, basically the entire expression parsed down into it’s most basic form

Implementations

Source

impl HistoryEntry

pub fn new(expression: &Token, session: &Session) -> Self

Creates a new entry struct from parser tokens and the desired amount of decimal places to render.

pub fn to_string(&self) -> String

Converts the entry to a string.

pub fn only_equality(&self) -> &Token

Gets the entry with only the equality

pub fn render_without_equality(&self, session: &Session) -> String

Renders the entry without an equal sign, nor everything right of it.

Just returns the expression unmodified if there is no equal sign.